@@ -183,7 +183,7 @@ with all the intermediate files\?
 
 By default, each time the CPAN module is started, cache scanning is
 performed to keep the cache size in sync. To prevent this, answer
-'never'.  
+'never'.
 
 });
 
@@ -258,6 +258,25 @@ set this variable, please hit SPACE RETURN to the following question.
       $CPAN::Config->{histsize} = $ans;
     }
 
+    #
+    # do an ls on the m or the d command
+    #
+    $CPAN::Frontend->myprint( qq{
+
+The 'd' and the 'm' command normally only show you information they
+have in their in-memory database and thus will never connect to the
+internet. If you set the 'show_upload_date' variable to true, 'm' and
+'d' will additionally show you the upload date of the module or
+distribution. Per default this feature is off because it may require a
+net connection to get at the upload date.
+
+});
+
+    defined($default = $CPAN::Config->{show_upload_date}) or
+        $default = 0;
+    $ans = prompt("Always try to show upload date with 'd' and 'm' command?", $default);
+    $CPAN::Config->{show_upload_date} = $ans;
+
     #
     # prerequisites_policy
     # Do we follow PREREQ_PM?
@@ -391,7 +410,7 @@ Cautious people will probably prefer:
 
     sudo make
 or
-    /usr/bin/sudo -u admin /usr/bin/make
+    /path1/to/sudo -u admin_account /path2/to/make
 
 or some such. Your choice: ",$default);
 
